@@ -23,7 +23,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -67,6 +67,7 @@ struct _GtkLabel
   guint   GSEAL (in_click)         : 1;
   guint   GSEAL (wrap_mode)        : 3;
   guint   GSEAL (pattern_set)      : 1;
+  guint   GSEAL (track_links)      : 1;
 
   guint   GSEAL (mnemonic_keyval);
 
@@ -96,11 +97,13 @@ struct _GtkLabelClass
   void (* populate_popup)   (GtkLabel       *label,
                              GtkMenu        *menu);
 
+  gboolean (*activate_link) (GtkLabel       *label,
+                             const gchar    *uri);
+
   /* Padding for future expansion */
   void (*_gtk_reserved1) (void);
   void (*_gtk_reserved2) (void);
   void (*_gtk_reserved3) (void);
-  void (*_gtk_reserved4) (void);
 };
 
 GType                 gtk_label_get_type          (void) G_GNUC_CONST;
@@ -174,20 +177,16 @@ void         gtk_label_set_single_line_mode  (GtkLabel *label,
                                               gboolean single_line_mode);
 gboolean     gtk_label_get_single_line_mode  (GtkLabel *label);
 
-#ifndef GTK_DISABLE_DEPRECATED
+G_CONST_RETURN gchar *gtk_label_get_current_uri (GtkLabel *label);
+void         gtk_label_set_track_visited_links  (GtkLabel *label,
+                                                 gboolean  track_links);
+gboolean     gtk_label_get_track_visited_links  (GtkLabel *label);
 
-#define  gtk_label_set           gtk_label_set_text
-void       gtk_label_get           (GtkLabel          *label,
-                                    gchar            **str);
 
-/* Convenience function to set the name and pattern by parsing
- * a string with embedded underscores, and return the appropriate
- * key symbol for the accelerator.
- */
-guint gtk_label_parse_uline            (GtkLabel    *label,
-					const gchar *string);
+/* private */
 
-#endif /* GTK_DISABLE_DEPRECATED */
+void _gtk_label_mnemonics_visible_apply_recursively (GtkWidget *widget,
+                                                     gboolean   mnemonics_visible);
 
 G_END_DECLS
 
