@@ -397,15 +397,9 @@ gtk_scrolled_window_init (GtkScrolledWindow *scrolled_window)
  * gtk_scrolled_window_new:
  * @hadjustment: (allow-none): horizontal adjustment
  * @vadjustment: (allow-none): vertical adjustment
-<<<<<<< HEAD
  *
  * Creates a new scrolled window.
  *
-=======
- *
- * Creates a new scrolled window.
- *
->>>>>>> native-layout-incubator
  * The two arguments are the scrolled window's adjustments; these will be
  * shared with the scrollbars and the child widget to keep the bars in sync 
  * with the child. Usually you want to pass %NULL for the adjustments, which 
@@ -1220,8 +1214,6 @@ gtk_scrolled_window_scroll_child (GtkScrolledWindow *scrolled_window,
 	  break;
 	}
 
-      value = CLAMP (value, adjustment->lower, adjustment->upper - adjustment->page_size);
-      
       gtk_adjustment_set_value (adjustment, value);
 
       return TRUE;
@@ -1513,13 +1505,11 @@ gtk_scrolled_window_scroll_event (GtkWidget      *widget,
   if (range && gtk_widget_get_visible (range))
     {
       GtkAdjustment *adj = GTK_RANGE (range)->adjustment;
-      gdouble delta, new_value;
+      gdouble delta;
 
       delta = _gtk_range_get_wheel_delta (GTK_RANGE (range), event->direction);
 
-      new_value = CLAMP (adj->value + delta, adj->lower, adj->upper - adj->page_size);
-      
-      gtk_adjustment_set_value (adj, new_value);
+      gtk_adjustment_set_value (adj, adj->value + delta);
 
       return TRUE;
     }
