@@ -21,8 +21,6 @@
 
 #include <string.h>
 
-#undef GTK_DISABLE_DEPRECATED
-
 #include <gtk/gtk.h>
 #ifdef GDK_WINDOWING_X11
 #include <gdk/x11/gdkx.h>
@@ -382,7 +380,7 @@ gail_widget_ref_relation_set (AtkObject *obj)
 
   relation_set = ATK_OBJECT_CLASS (gail_widget_parent_class)->ref_relation_set (obj);
 
-  if (GTK_IS_BOX (widget) && !GTK_IS_COMBO (widget))
+  if (GTK_IS_BOX (widget))
       /*
        * Do not report labelled-by for a GtkBox which could be a 
        * GnomeFileEntry.
@@ -417,26 +415,6 @@ gail_widget_ref_relation_set (AtkObject *obj)
                     }
                 }
             }
-          else if (GTK_IS_COMBO (widget))
-            /*
-             * Handle the case when GnomeFileEntry is the mnemonic widget.
-             * The GnomeEntry which is a grandchild of the GnomeFileEntry
-             * should be the mnemonic widget. See bug #137584.
-             */
-            {
-              GtkWidget *temp_widget;
-
-              temp_widget = gtk_widget_get_parent (widget);
-
-              if (GTK_IS_HBOX (temp_widget))
-                {
-                  temp_widget = gtk_widget_get_parent (temp_widget);
-                  if (GTK_IS_BOX (temp_widget))
-                    {
-                      label = find_label (temp_widget);
-                    }
-                }
-            }
           else if (GTK_IS_COMBO_BOX (widget))
             /*
              * Handle the case when GtkFileChooserButton is the mnemonic
@@ -482,13 +460,13 @@ gail_widget_ref_state_set (AtkObject *accessible)
     }
   else
     {
-      if (GTK_WIDGET_IS_SENSITIVE (widget))
+      if (gtk_widget_is_sensitive (widget))
         {
           atk_state_set_add_state (state_set, ATK_STATE_SENSITIVE);
           atk_state_set_add_state (state_set, ATK_STATE_ENABLED);
         }
   
-      if (GTK_WIDGET_CAN_FOCUS (widget))
+      if (gtk_widget_get_can_focus (widget))
         {
           atk_state_set_add_state (state_set, ATK_STATE_FOCUSABLE);
         }
@@ -511,17 +489,17 @@ gail_widget_ref_state_set (AtkObject *accessible)
        * GailWidget data structure so we can determine whether the value has 
        * changed.
        */
-      if (GTK_WIDGET_VISIBLE (widget))
+      if (gtk_widget_get_visible (widget))
         {
           atk_state_set_add_state (state_set, ATK_STATE_VISIBLE);
-          if (gail_widget_on_screen (widget) && GTK_WIDGET_MAPPED (widget) &&
+          if (gail_widget_on_screen (widget) && gtk_widget_get_mapped (widget) &&
               gail_widget_all_parents_visible (widget))
             {
               atk_state_set_add_state (state_set, ATK_STATE_SHOWING);
             }
         }
   
-      if (GTK_WIDGET_HAS_FOCUS (widget) && (widget == focus_widget))
+      if (gtk_widget_has_focus (widget) && (widget == focus_widget))
         {
           AtkObject *focus_obj;
 
@@ -529,7 +507,7 @@ gail_widget_ref_state_set (AtkObject *accessible)
           if (focus_obj == NULL)
             atk_state_set_add_state (state_set, ATK_STATE_FOCUSED);
         }
-      if (GTK_WIDGET_HAS_DEFAULT(widget))
+      if (gtk_widget_has_default (widget))
         {
           atk_state_set_add_state (state_set, ATK_STATE_DEFAULT);
         }
@@ -666,7 +644,7 @@ gail_widget_get_extents (AtkComponent   *component,
 
   *width = widget->allocation.width;
   *height = widget->allocation.height;
-  if (!gail_widget_on_screen (widget) || (!GTK_WIDGET_DRAWABLE (widget)))
+  if (!gail_widget_on_screen (widget) || (!gtk_widget_is_drawable (widget)))
     {
       *x = G_MININT;
       *y = G_MININT;
@@ -735,11 +713,11 @@ gail_widget_grab_focus (AtkComponent   *component)
   GtkWidget *toplevel;
 
   gail_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
-  if (GTK_WIDGET_CAN_FOCUS (widget))
+  if (gtk_widget_get_can_focus (widget))
     {
       gtk_widget_grab_focus (widget);
       toplevel = gtk_widget_get_toplevel (widget);
-      if (GTK_WIDGET_TOPLEVEL (toplevel))
+      if (gtk_widget_is_toplevel (toplevel))
 	{
 #ifdef GDK_WINDOWING_X11
 	  gtk_window_present_with_time (GTK_WINDOW (toplevel), gdk_x11_get_server_time (widget->window));
@@ -777,7 +755,7 @@ gail_widget_set_extents (AtkComponent   *component,
     return FALSE;
   gail_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
 
-  if (GTK_WIDGET_TOPLEVEL (widget))
+  if (gtk_widget_is_toplevel (widget))
     {
       if (coord_type == ATK_XY_WINDOW)
         {
@@ -791,14 +769,14 @@ gail_widget_set_extents (AtkComponent   *component,
             return FALSE;
           else
             {
-              gtk_widget_set_uposition (widget, x_current, y_current);
+              gtk_window_move (GTK_WINDOW (widget), x_current, y_current);
               gtk_widget_set_size_request (widget, width, height);
               return TRUE;
             }
         }
       else if (coord_type == ATK_XY_SCREEN)
-        {  
-          gtk_widget_set_uposition (widget, x, y);
+        {
+          gtk_window_move (GTK_WINDOW (widget), x, y);
           gtk_widget_set_size_request (widget, width, height);
           return TRUE;
         }
@@ -821,7 +799,7 @@ gail_widget_set_position (AtkComponent   *component,
     return FALSE;
   gail_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
 
-  if (GTK_WIDGET_TOPLEVEL (widget))
+  if (gtk_widget_is_toplevel (widget))
     {
       if (coord_type == ATK_XY_WINDOW)
         {
@@ -835,13 +813,13 @@ gail_widget_set_position (AtkComponent   *component,
             return FALSE;
           else
             {
-              gtk_widget_set_uposition (widget, x_current, y_current);
+              gtk_window_move (GTK_WINDOW (widget), x_current, y_current);
               return TRUE;
             }
         }
       else if (coord_type == ATK_XY_SCREEN)
-        {  
-          gtk_widget_set_uposition (widget, x, y);
+        {
+          gtk_window_move (GTK_WINDOW (widget), x, y);
           return TRUE;
         }
     }
@@ -862,7 +840,7 @@ gail_widget_set_size (AtkComponent   *component,
     return FALSE;
   gail_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
 
-  if (GTK_WIDGET_TOPLEVEL (widget))
+  if (gtk_widget_is_toplevel (widget))
     {
       gtk_widget_set_size_request (widget, width, height);
       return TRUE;
@@ -937,7 +915,7 @@ gail_widget_map_gtk (GtkWidget     *widget)
 
   accessible = gtk_widget_get_accessible (widget);
   atk_object_notify_state_change (accessible, ATK_STATE_SHOWING,
-                                  GTK_WIDGET_MAPPED (widget));
+                                  gtk_widget_get_mapped (widget));
   return 1;
 }
 
@@ -986,17 +964,20 @@ gail_widget_real_notify_gtk (GObject     *obj,
   else if (strcmp (pspec->name, "visible") == 0)
     {
       state = ATK_STATE_VISIBLE;
-      value = GTK_WIDGET_VISIBLE (widget);
+      value = gtk_widget_get_visible (widget);
     }
   else if (strcmp (pspec->name, "sensitive") == 0)
     {
       state = ATK_STATE_SENSITIVE;
-      value = GTK_WIDGET_SENSITIVE (widget);
+      value = gtk_widget_get_sensitive (widget);
     }
   else
     return;
 
   atk_object_notify_state_change (atk_obj, state, value);
+  if (state == ATK_STATE_SENSITIVE)
+    atk_object_notify_state_change (atk_obj, ATK_STATE_ENABLED, value);
+
 }
 
 static void 
@@ -1093,7 +1074,7 @@ static gboolean gail_widget_all_parents_visible (GtkWidget *widget)
   for (iter_parent = gtk_widget_get_parent (widget); iter_parent;
        iter_parent = gtk_widget_get_parent (iter_parent))
     {
-      if (!GTK_WIDGET_VISIBLE (iter_parent))
+      if (!gtk_widget_get_visible (iter_parent))
         {
           result = FALSE;
           break;
